@@ -2,11 +2,11 @@
 
 import yaml
 
-from simmate.calculators.vasp.inputs import Potcar
+from simmate.apps.vasp.inputs import Potcar
 from simmate.command_line.workflows import workflows_app
 from simmate.conftest import make_dummy_files
-from simmate.workflow_engine import Workflow
-from simmate.workflow_engine.workflow import DummyState
+from simmate.engine import Workflow
+from simmate.engine.workflow import DummyState
 
 
 def test_workflows_list_all(command_line_runner):
@@ -16,7 +16,6 @@ def test_workflows_list_all(command_line_runner):
 
 
 def test_workflows_show_config(command_line_runner):
-
     # list the config for one workflow
     result = command_line_runner.invoke(
         workflows_app,
@@ -33,7 +32,6 @@ def test_workflows_show_config(command_line_runner):
 
 
 def test_workflows_explore(command_line_runner):
-
     # Make sure it passes when args match
     result = command_line_runner.invoke(
         workflows_app,
@@ -52,7 +50,6 @@ def test_workflows_explore(command_line_runner):
 
 
 def test_workflows_setup_only(command_line_runner, structure, mocker, tmp_path):
-
     # establish filenames
     cif_filename = str(tmp_path / "test.cif")
     new_dirname = tmp_path / "inputs"  # changed to str below
@@ -67,7 +64,7 @@ def test_workflows_setup_only(command_line_runner, structure, mocker, tmp_path):
     )
 
     # write the structure to file to be used
-    structure.to("cif", cif_filename)
+    structure.to(filename=str(cif_filename), fmt="cif")
 
     # now try writing input files to the tmp_path
     result = command_line_runner.invoke(
@@ -93,13 +90,12 @@ def test_workflows_setup_only(command_line_runner, structure, mocker, tmp_path):
 
 
 def test_workflows_run(command_line_runner, structure, mocker, tmp_path):
-
     # establish filenames
     cif_filename = str(tmp_path / "test.cif")
     new_dirname = str(tmp_path / "inputs")
 
     # write the structure to file to be used
-    structure.to("cif", cif_filename)
+    structure.to(filename=str(cif_filename), fmt="cif")
 
     # I don't want to actually run the workflow, so I override the run method
     mocker.patch.object(
@@ -138,14 +134,13 @@ def test_workflows_run(command_line_runner, structure, mocker, tmp_path):
 
 
 def test_workflows_run_yaml(command_line_runner, structure, mocker, tmp_path):
-
     # establish filenames
     cif_filename = str(tmp_path / "test.cif")
     yaml_filename = str(tmp_path / "test.yaml")
     new_dirname = str(tmp_path / "inputs")
 
     # write the structure to file to be used
-    structure.to("cif", cif_filename)
+    structure.to(filename=str(cif_filename), fmt="cif")
 
     # write the yaml file with our input args
     input_args = dict(
