@@ -21,12 +21,12 @@ import pytest
 from django.contrib.auth.models import User
 from typer.testing import CliRunner
 
-from simmate.calculators.vasp.inputs import Potcar
+from simmate.apps.vasp.inputs import Potcar
 from simmate.database.base_data_types import Spacegroup
+from simmate.engine import S3Workflow
 from simmate.toolkit import Composition, Structure, base_data_types
 from simmate.utilities import get_directory
 from simmate.website.test_app.models import TestStructure
-from simmate.workflow_engine import S3Workflow
 
 COMPOSITIONS_STRS = [
     "Fe1",
@@ -167,7 +167,6 @@ def django_db_setup(
     and a user.
     """
     with django_db_blocker.unblock():
-
         # add a user
         User.objects.create_user(
             username="test_user",
@@ -283,7 +282,6 @@ def make_dummy_files(*filenames: str):
 class SimmateMockHelper:
     @staticmethod
     def get_mocked_potcar(mocker, directory: Path):
-
         # Because we won't have POTCARs accessible, we need to cover this function
         # call -- specifically have it pretend to make a file
         mocker.patch.object(
@@ -295,7 +293,6 @@ class SimmateMockHelper:
         return Potcar  # in case we need to "assert_called_with"
 
     def mock_vasp(mocker):
-
         # Because we won't have POTCARs accessible, we need to skip this function
         # call -- specifically have it pretend to make a file
         mocker.patch.object(Potcar, "to_file_from_type", return_value=None)
